@@ -115,10 +115,6 @@ See the detail of the L<socket|https://linux.die.net/man/2/socket> function in t
 
 If the system call failed, an exception will be thrown with the error code set to the class id of the L<Error::System> class.
 
-=head2 connect_raw
-
-C<static method connect_raw : int ($sockfd : int, $addr : L<Sys::Socket::Sockaddr|SPVM::Sys::Socket::Sockaddr>, $addrlen : int);>
-
 =head2 connect
 
 C<static method connect : int ($sockfd : int, $addr : L<Sys::Socket::Sockaddr|SPVM::Sys::Socket::Sockaddr>, $addrlen : int);>
@@ -285,14 +281,6 @@ $optval is a string. The following is an example to get an int value.
   Fn->memcpy($result_ref, 0, $optval, 0, 4);
   my $optval_int = $optval_int_ref->[0];
 
-=head2 getaddrinfo_raw
-
-C<static method getaddrinfo_raw : int ($node : string, $service : string,>
-                $hints : Sys::Socket::Addrinfo,
-                $res : Sys::Socket::Addrinfo[]);
-
-Same as the L</"getaddrinfo"> method, but doesn't throw exceptions related to system errors.
-
 =head2 getaddrinfo
 
 C<static method getaddrinfo : int ($node : string, $service : string,>
@@ -313,14 +301,6 @@ The length of the array of the response must be greater than or equal to 1. Othe
 
 If a system error occur, an exception will be thrown with the error code set to the class id of the L<Error::System> class.
 
-=head2 getnameinfo_raw
-
-C<static method getnameinfo_raw : int ($sa : L<Sys::Socket::Sockaddr|SPVM::Sys::Socket::Sockaddr>, $salen : int,>
-                $host : mutable string, $hostlen : int,
-                $serv : mutable string, $servlen : int, $flags : int);
-
-Same as the L</"getnameinfo"> method, but doesn't throw exceptions related to system errors.
-
 =head2 getnameinfo
 
 C<static method getnameinfo : int ($sa : L<Sys::Socket::Sockaddr|SPVM::Sys::Socket::Sockaddr>, $salen : int,>
